@@ -11,7 +11,7 @@ use Pod::Usage ();
 use Cwd 'abs_path';
 use Config;
 
-our $VERSION = '0.116';
+our $VERSION = '0.117';
 
 sub new {
     my ($class, %option) = @_;
@@ -51,7 +51,7 @@ sub parse_options {
     $self->{color} = 1 if !defined $self->{color} && -t STDOUT;
     if ($target_perl) {
         # 5.8 is interpreted as 5.800, fix it
-        $target_perl = "v$target_perl" if $target_perl =~ /^5\.[1-9]\d+$/;
+        $target_perl = "v$target_perl" if $target_perl =~ /^5\.[1-9]\d*$/;
         $self->{target_perl} = App::cpm::version->parse($target_perl)->numify;
         if ($self->{target_perl} > $]) {
             die "--target-perl must be lower than your perl version $]\n";
@@ -149,18 +149,18 @@ sub cmd_install {
         $worker->run_loop;
     };
 
-    my $git;
     my @package;
     for my $arg (@argv) {
-        if ($arg =~ /(?:^git:|\.git(?:@.+)?$)/) {
+        if (-d $arg or $arg =~ /(?:^git:|\.git(?:@.+)?$)/) {
+            $arg = abs_path $arg if -d $arg;
             my $dist = App::cpm::Distribution->new(distfile => $arg, provides => []);
             $master->add_distribution($dist);
-            $git++;
         } else {
             push @package, {package => $arg, version => 0};
         }
     }
-    if (!$git && !@package) {
+
+    if (!@argv) {
         if (-f $self->{snapshot}) {
             warn "Loading distributions from $self->{snapshot}...\n";
             $master->add_distribution($_) for $self->load_snapshot($self->{snapshot});
@@ -169,7 +169,8 @@ sub cmd_install {
             my $requirements = $self->load_cpanfile($self->{cpanfile});
             my ($is_satisfied, @need_resolve) = $master->is_satisfied($requirements);
             if ($is_satisfied) {
-                warn "All requirements are satisfied.\n"; exit;
+                warn "All requirements are satisfied.\n";
+                return 0; # exit 0
             } elsif (!defined $is_satisfied) {
                 my ($req) = grep { $_->{package} eq "perl" } @$requirements;
                 die sprintf "%s requires perl %s\n", $self->{cpanfile}, $req->{version};
